Rietveld Code Review Tool
Help | Bug tracker | Discussion group | Source code

Unified Diff: include.preload.js

Issue 29338716: Issue 2687 - Don't use Shadow DOM on blogger.com (Closed)
Patch Set: Wrapped long line Created March 19, 2016, 3:20 p.m.
Use n/p to move between diff chunks; N/P to move between comments.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include.preload.js
===================================================================
--- a/include.preload.js
+++ b/include.preload.js
@@ -409,8 +409,9 @@
// have to create the shadow root before transistions might start (#452).
//
// Also, using shadow DOM causes issues on some Google websites,
- // including Google Docs and Gmail (#1770, #2602).
- if ("createShadowRoot" in document.documentElement && !/\.google\.com$/.test(document.domain))
+ // including Google Docs, Gmail and Blogger (#1770, #2602, #2687).
+ if ("createShadowRoot" in document.documentElement &&
+ !/\.(?:google|blogger)\.com$/.test(document.domain))
{
shadow = document.documentElement.createShadowRoot();
shadow.appendChild(document.createElement("shadow"));
« no previous file with comments | « no previous file | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld